yt.data\_objects.selection\_objects package
===========================================

Submodules
----------

.. toctree::
   :maxdepth: 4

   yt.data_objects.selection_objects.boolean_operations
   yt.data_objects.selection_objects.cut_region
   yt.data_objects.selection_objects.data_selection_objects
   yt.data_objects.selection_objects.disk
   yt.data_objects.selection_objects.object_collection
   yt.data_objects.selection_objects.point
   yt.data_objects.selection_objects.ray
   yt.data_objects.selection_objects.region
   yt.data_objects.selection_objects.slices
   yt.data_objects.selection_objects.spheroids

Module contents
---------------

.. automodule:: yt.data_objects.selection_objects
   :members:
   :undoc-members:
   :inherited-members:
   :show-inheritance:
